@@ -5,6 +5,7 @@ import re
 import sys
 import time
 
+from . import VERSION
 from .util import arg_dict, cute_str
 
 
@@ -125,6 +126,15 @@ def cli_init(args):
 
     # Create our passcrow object and directories
     pc = make_pc(args, create_dirs=True)
+
+    # Enable the test server by default
+    pc.default_policy.servers = ['mailto via passcrow-test.mailpile.is']
+    sys.stderr.write("""\
+NOTE: Configuring `passcrow-test.mailpile.is` as the default server for
+      e-mail (mailto) verification. Note that this server is for testing
+      only and deletes all data after 30 days, no matter what expiration
+      has been requested/promised.\n\n""")
+
     saved = pc.save_default_policy()
     sys.stderr.write(
         'Edit your default Passcrow policy here: %s\n' % cute_str(saved))
@@ -199,10 +209,10 @@ def cli_protect(args):
     Options:
         -b            Batch mode, generates machine-readable output
         -n <NAME>     Description in passcrow database (required for stdin)
-        -q            Quick operation (reduced anonymity)
         -e            Ephemeral: local storage optional, small secrets only
         -E            Ephemeral only: skip local storage, small secrets only
     """
+    # FIXME: -q       Quick operation (reduced anonymity)
     # FIXME: -f = force, otherwise refuse to clobber existing secrets?
 
     args = arg_dict(args,
@@ -218,7 +228,7 @@ def cli_protect(args):
     if not ephemeral:
         ephemeral = args.get('-E', False) and EPHEMERAL_ONLY
 
-    quick = args.get('-q', False)
+    quick = args.get('-q', False) or True  # FIXME
     batch = args.get('-b', False)
     source = args['_'].pop(0)
     try:
@@ -296,7 +306,6 @@ def cli_recover(args):
     Options:
         -o <FILENAME> Write recovered data to file (default is stdout)
         -b            Batch mode, generates machine-readable output
-        -q            Quick operation (reduced anonymity)
 
     Batch mode will always output a JSON object describing the recovery
     progress. Recovered data, if present, is base64 encoded.
@@ -308,7 +317,7 @@ def cli_recover(args):
 
     # FIXME: -o does not work
 
-    quick = args.get('-q', False)
+    quick = args.get('-q', False) or True  # FIXME
     batch = args.get('-b', False)
     name = args['_'].pop(0)
     codes = args['_']
@@ -379,7 +388,7 @@ Verification initiated!
 When you have received the codes, please re-run `passcrow recover`
 with the codes as arguments. For example:
 
-passcrow recover "%s" %s
+    passcrow recover "%s" %s
 
 You must provide at least %d code(s) within %d minutes.""" % (
                     hint_list, url_list,
@@ -407,14 +416,13 @@ def cli_forget(args):
         passcrow forget "Secret 1" "Secret 2"
 
     Options:
-        -q            Quick operation (reduced anonymity)
         -l            Local only (do not contact remote servers)
     """
     args = arg_dict(args, options='C:D:H:Tlq', bare_args=True,
                           invalid_exc=UsageError)
 
     names = args['_']
-    quick = args.get('-q', False)
+    quick = args.get('-q', False) or True  # FIXME
     noremote = args.get('-l', False)
     pc = make_pc(args)
 
@@ -464,6 +472,8 @@ def cli_server_init(args):
 
 def cli_help(args, error=None):
     """
+    This is python-passcrow version @VERSION@.
+
     Passcrow is a tool to facilitate secure password/passphrase/key
     recovery when using local encryption.
 
@@ -482,7 +492,7 @@ def cli_help(args, error=None):
     configuration file it generates.
 
     Run `passcrow help COMMAND` for more details about each command.
-    """
+"""
     if error:
         p = lambda t: sys.stderr.write('%s\n' % t)
     else:
@@ -522,6 +532,8 @@ def cli_main(args):
     return False
 
 
+cli_help.__doc__ = cli_help.__doc__.replace('@VERSION@', VERSION)
+
 CLI_COMMANDS.update({
     'server_init': cli_server_init,
     'init': cli_init,
@@ -532,4 +544,9 @@ CLI_COMMANDS.update({
     'help': cli_help})
 
 
-sys.exit(0 if cli_main(sys.argv[1:]) else 1)
+def main():
+    sys.exit(0 if cli_main(sys.argv[1:]) else 1)
+
+
+if __name__ == '__main__':
+    main()
